[jboss-cvs] JBossAS SVN: r86545 - in projects/jboss-jsf-int/trunk: cargo and 17 other directories.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Tue Mar 31 16:22:31 EDT 2009


Author: stan.silvert at jboss.com
Date: 2009-03-31 16:22:31 -0400 (Tue, 31 Mar 2009)
New Revision: 86545

Added:
   projects/jboss-jsf-int/trunk/cargo/ASModifications/
   projects/jboss-jsf-int/trunk/cargo/ASModifications/deploy/
   projects/jboss-jsf-int/trunk/cargo/ASModifications/deploy/jbossweb.sar/
   projects/jboss-jsf-int/trunk/cargo/ASModifications/deploy/jbossweb.sar/META-INF/
   projects/jboss-jsf-int/trunk/cargo/ASModifications/deploy/jbossweb.sar/META-INF/jboss-structure.xml
   projects/jboss-jsf-int/trunk/cargo/ASModifications/deploy/jbossweb.sar/jsf-libs/
   projects/jboss-jsf-int/trunk/cargo/ASModifications/deployers/
   projects/jboss-jsf-int/trunk/cargo/ASModifications/deployers/jbossweb.deployer/
   projects/jboss-jsf-int/trunk/cargo/ASModifications/deployers/jbossweb.deployer/web.xml
   projects/jboss-jsf-int/trunk/cargo/ASModifications/deployers/jsf.deployer/
   projects/jboss-jsf-int/trunk/cargo/ASModifications/deployers/jsf.deployer/META-INF/
   projects/jboss-jsf-int/trunk/cargo/ASModifications/deployers/jsf.deployer/META-INF/jsf-integration-deployer-jboss-beans.xml
   projects/jboss-jsf-int/trunk/cargo/ASModifications/deployers/jsf.deployer/Mojarra-1.2/
   projects/jboss-jsf-int/trunk/cargo/ASModifications/deployers/jsf.deployer/Mojarra-1.2/web.xml
   projects/jboss-jsf-int/trunk/cargo/ASModifications/deployers/jsf.deployer/Mojarra-2.0/
   projects/jboss-jsf-int/trunk/cargo/ASModifications/deployers/jsf.deployer/Mojarra-2.0/web.xml
   projects/jboss-jsf-int/trunk/cargo/src/test/java/org/jboss/jsf/integration/test/DeployJSF20Test.java
Removed:
   projects/jboss-jsf-int/trunk/jsf-deployer/src/main/resources/
Modified:
   projects/jboss-jsf-int/trunk/cargo/
   projects/jboss-jsf-int/trunk/cargo/pom.xml
   projects/jboss-jsf-int/trunk/jsf-deployer/
   projects/jboss-jsf-int/trunk/jsf-deployer/src/main/java/org/jboss/jsf/integration/JSFDeployer.java
   projects/jboss-jsf-int/trunk/jsf12test/
   projects/jboss-jsf-int/trunk/jsf20test/
   projects/jboss-jsf-int/trunk/pom.xml
   projects/jboss-jsf-int/trunk/testwar/
Log:
JBAS-6638 Move JSF integration into a deployer



Property changes on: projects/jboss-jsf-int/trunk/cargo
___________________________________________________________________
Name: svn:ignore
   + target


Added: projects/jboss-jsf-int/trunk/cargo/ASModifications/deploy/jbossweb.sar/META-INF/jboss-structure.xml
===================================================================
--- projects/jboss-jsf-int/trunk/cargo/ASModifications/deploy/jbossweb.sar/META-INF/jboss-structure.xml	                        (rev 0)
+++ projects/jboss-jsf-int/trunk/cargo/ASModifications/deploy/jbossweb.sar/META-INF/jboss-structure.xml	2009-03-31 20:22:31 UTC (rev 86545)
@@ -0,0 +1,14 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<structure>
+    <context>
+        <path name=""/>
+        <metaDataPath>
+            <path name="META-INF"/>
+        </metaDataPath>        
+        <classpath>
+            <path name=""/>
+            <path name="" suffixes=".jar" />
+       <!--     <path name="jsf-libs" suffixes=".jar" />  -->
+        </classpath>
+    </context>
+</structure>

Added: projects/jboss-jsf-int/trunk/cargo/ASModifications/deployers/jbossweb.deployer/web.xml
===================================================================
--- projects/jboss-jsf-int/trunk/cargo/ASModifications/deployers/jbossweb.deployer/web.xml	                        (rev 0)
+++ projects/jboss-jsf-int/trunk/cargo/ASModifications/deployers/jbossweb.deployer/web.xml	2009-03-31 20:22:31 UTC (rev 86545)
@@ -0,0 +1,992 @@
+<?xml version="1.0" encoding="ISO-8859-1"?>
+<web-app xmlns="http://java.sun.com/xml/ns/javaee"
+   xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
+   xsi:schemaLocation="http://java.sun.com/xml/ns/javaee http://java.sun.com/xml/ns/javaee/web-app_2_5.xsd"
+   version="2.5">
+   <!-- ======================== Introduction ============================== -->
+   <!-- This document defines default values for *all* web applications      -->
+   <!-- loaded into this instance of Tomcat.  As each application is         -->
+   <!-- deployed, this file is processed, followed by the                    -->
+   <!-- "/WEB-INF/web.xml" deployment descriptor from your own               -->
+   <!-- applications.                                                        -->
+   <!--                                                                      -->
+   <!-- WARNING:  Do not configure application-specific resources here!      -->
+   <!-- They should go in the "/WEB-INF/web.xml" file in your application.   -->
+
+   <!-- =========== Common Context Params ================================== -->
+
+   <!-- ================== Common filter Configuration ==================== -->
+   <filter>
+      <filter-name>CommonHeadersFilter</filter-name>
+      <filter-class>
+         org.jboss.web.tomcat.filters.ReplyHeaderFilter</filter-class>
+      <init-param>
+         <param-name>X-Powered-By</param-name>
+         <param-value>Servlet 2.5; JBoss-5.0/JBossWeb-2.1</param-value>
+      </init-param>
+   </filter>
+
+   <filter-mapping>
+      <filter-name>CommonHeadersFilter</filter-name>
+      <url-pattern>/*</url-pattern>
+   </filter-mapping>
+	
+   <!-- ================== Common Listener Configuration ==================== -->
+   <listener>
+      <listener-class>org.jboss.web.tomcat.security.SecurityFlushSessionListener</listener-class>
+   </listener>
+
+   <!-- ================== Built In Servlet Definitions ==================== -->
+
+
+   <!-- The default servlet for all web applications, that serves static     -->
+   <!-- resources.  It processes all requests that are not mapped to other   -->
+   <!-- servlets with servlet mappings (defined either here or in your own   -->
+   <!-- web.xml file.  This servlet supports the following initialization    -->
+   <!-- parameters (default values are in square brackets):                  -->
+   <!--                                                                      -->
+   <!--   debug               Debugging detail level for messages logged     -->
+   <!--                       by this servlet.  [0]                          -->
+   <!--                                                                      -->
+   <!--   input               Input buffer size (in bytes) when reading      -->
+   <!--                       resources to be served.  [2048]                -->
+   <!--                                                                      -->
+   <!--   listings            Should directory listings be produced if there -->
+   <!--                       is no welcome file in this directory?  [true]  -->
+   <!--                                                                      -->
+   <!--   output              Output buffer size (in bytes) when writing     -->
+   <!--                       resources to be served.  [2048]                -->
+   <!--                                                                      -->
+   <!--   readonly            Is this context "read only", so HTTP           -->
+   <!--                       commands like PUT and DELETE are               -->
+   <!--                       rejected?  [true]                              -->
+   <!--                                                                      -->
+   <!--   readmeFile          File name to display with the directory        -->
+   <!--                       contents. [null]                               -->
+   <!--                                                                      -->
+   <!--  For directory listing customization. Checks localXsltFile, then     -->
+   <!--  globalXsltFile, then defaults to original behavior.                 -->
+   <!--                                                                      -->
+   <!--   localXsltFile       Make directory listings an XML doc and         -->
+   <!--                       pass the result to this style sheet residing   -->
+   <!--                       in that directory. This overrides              -->
+   <!--                        globalXsltFile[null]                          -->
+   <!--                                                                      -->
+   <!--   globalXsltFile      Site wide configuration version of             -->
+   <!--                       localXsltFile This argument is expected        -->
+   <!--                       to be a physical file. [null]                  -->
+   <!--                                                                      -->
+   <!--                                                                      -->
+
+   <servlet>
+      <servlet-name>default</servlet-name>
+      <servlet-class>org.apache.catalina.servlets.DefaultServlet</servlet-class>
+      <init-param>
+         <param-name>debug</param-name>
+         <param-value>0</param-value>
+      </init-param>
+      <init-param>
+         <param-name>listings</param-name>
+         <param-value>false</param-value>
+      </init-param>
+      <load-on-startup>1</load-on-startup>
+   </servlet>
+
+
+   <!-- The "invoker" servlet, which executes anonymous servlet classes      -->
+   <!-- that have not been defined in a web.xml file.  Traditionally, this   -->
+   <!-- servlet is mapped to the URL pattern "/servlet/*", but you can map   -->
+   <!-- it to other patterns as well.  The extra path info portion of such a -->
+   <!-- request must be the fully qualified class name of a Java class that  -->
+   <!-- implements Servlet (or extends HttpServlet), or the servlet name     -->
+   <!-- of an existing servlet definition.     This servlet supports the     -->
+   <!-- following initialization parameters (default values are in square    -->
+   <!-- brackets):                                                           -->
+   <!--                                                                      -->
+   <!--   debug               Debugging detail level for messages logged     -->
+   <!--                       by this servlet.  [0]                          -->
+
+   <!--
+       <servlet>
+           <servlet-name>invoker</servlet-name>
+           <servlet-class>
+             org.apache.catalina.servlets.InvokerServlet
+           </servlet-class>
+           <init-param>
+               <param-name>debug</param-name>
+               <param-value>0</param-value>
+           </init-param>
+           <load-on-startup>2</load-on-startup>
+       </servlet>
+   -->
+
+
+   <!-- The JSP page compiler and execution servlet, which is the mechanism  -->
+   <!-- used by Tomcat to support JSP pages.  Traditionally, this servlet    -->
+   <!-- is mapped to the URL pattern "*.jsp".  This servlet supports the     -->
+   <!-- following initialization parameters (default values are in square    -->
+   <!-- brackets):                                                           -->
+   <!--                                                                      -->
+   <!--   checkInterval       If development is false and checkInterval is   -->
+   <!--                       greater than zero, background compilations are -->
+   <!--                       enabled. checkInterval is the time in seconds  -->
+   <!--                       between checks to see if a JSP page needs to   -->
+   <!--                       be recompiled. [0]                             -->
+   <!--                                                                      -->
+   <!--   modificationTestInterval                                           -->
+   <!--                       Causes a JSP (and its dependent files) to not  -->
+   <!--                       be checked for modification during the         -->
+   <!--                       specified time interval (in seconds) from the  -->
+   <!--                       last time the JSP was checked for              -->
+   <!--                       modification. A value of 0 will cause the JSP  -->
+   <!--                       to be checked on every access.                 -->
+   <!--                       Used in development mode only. [4]             -->
+   <!--                                                                      -->
+   <!--   compiler            Which compiler Ant should use to compile JSP   -->
+   <!--                       pages.  See the Ant documentation for more     -->
+   <!--                       information.                                   -->
+   <!--                                                                      -->
+   <!--   classdebuginfo      Should the class file be compiled with         -->
+   <!--                       debugging information?  [true]                 -->
+   <!--                                                                      -->
+   <!--   classpath           What class path should I use while compiling   -->
+   <!--                       generated servlets?  [Created dynamically      -->
+   <!--                       based on the current web application]          -->
+   <!--                                                                      -->
+   <!--   development         Is Jasper used in development mode? If true,   -->
+   <!--                       the frequency at which JSPs are checked for    -->
+   <!--                       modification may be specified via the          -->
+   <!--                       modificationTestInterval parameter. [true]     -->
+   <!--                                                                      -->
+   <!--   enablePooling       Determines whether tag handler pooling is      -->
+   <!--                       enabled  [true]                                -->
+   <!--                                                                      -->
+   <!--   fork                Tell Ant to fork compiles of JSP pages so that -->
+   <!--                       a separate JVM is used for JSP page compiles   -->
+   <!--                       from the one Tomcat is running in. [true]      -->
+   <!--                                                                      -->
+   <!--   ieClassId           The class-id value to be sent to Internet      -->
+   <!--                       Explorer when using <jsp:plugin> tags.         -->
+   <!--                       [clsid:8AD9C840-044E-11D1-B3E9-00805F499D93]   -->
+   <!--                                                                      -->
+   <!--   javaEncoding        Java file encoding to use for generating java  -->
+   <!--                       source files. [UTF8]                           -->
+   <!--                                                                      -->
+   <!--   keepgenerated       Should we keep the generated Java source code  -->
+   <!--                       for each page instead of deleting it? [true]   -->
+   <!--                                                                      -->
+   <!--   mappedfile          Should we generate static content with one     -->
+   <!--                       print statement per input line, to ease        -->
+   <!--                       debugging?  [true]                             -->
+   <!--                                                                      -->
+   <!--   trimSpaces          Should white spaces in template text between   -->
+   <!--                       actions or directives be trimmed?  [false]     -->
+   <!--                                                                      -->
+   <!--   suppressSmap        Should the generation of SMAP info for JSR45   -->
+   <!--                       debugging be suppressed?  [false]              -->
+   <!--                                                                      -->
+   <!--   dumpSmap            Should the SMAP info for JSR45 debugging be    -->
+   <!--                       dumped to a file? [false]                      -->
+   <!--                       False if suppressSmap is true                  -->
+   <!--                                                                      -->
+   <!--   genStrAsCharArray   Should text strings be generated as char       -->
+   <!--                       arrays, to improve performance in some cases?  -->
+   <!--                       [false]                                        -->
+   <!--                                                                      -->
+   <!--   errorOnUseBeanInvalidClassAttribute                                -->
+   <!--                       Should Jasper issue an error when the value of -->
+   <!--                       the class attribute in an useBean action is    -->
+   <!--                       not a valid bean class?  [true]                -->
+   <!--                                                                      -->
+   <!--   scratchdir          What scratch directory should we use when      -->
+   <!--                       compiling JSP pages?  [default work directory  -->
+   <!--                       for the current web application]               -->
+   <!--                                                                      -->
+   <!--   xpoweredBy          Determines whether X-Powered-By response       -->
+   <!--                       header is added by generated servlet  [false]  -->
+   <!--                                                                      -->
+   <!-- If you wish to use Jikes to compile JSP pages:                       -->
+   <!--   Set the init parameter "compiler" to "jikes".  Define              -->
+   <!--   the property "-Dbuild.compiler.emacs=true" when starting Tomcat    -->
+   <!--   by adding the above to your CATALINA_OPTS environment variable.    -->
+   <!--   If you get an error reporting that jikes can't use UTF8 encoding,  -->
+   <!--   try setting the init parameter "javaEncoding" to "ISO-8859-1".     -->
+
+   <servlet>
+      <servlet-name>jsp</servlet-name>
+      <servlet-class>org.apache.jasper.servlet.JspServlet</servlet-class>
+      <init-param>
+         <param-name>fork</param-name>
+         <param-value>false</param-value>
+      </init-param>
+      <init-param>
+         <param-name>xpoweredBy</param-name>
+         <param-value>false</param-value>
+      </init-param>
+      <!-- Use jdk1.5 features in jsp pages -->
+      <init-param>
+         <param-name>compilerSourceVM</param-name>
+         <param-value>1.5</param-value>
+      </init-param>
+      <!-- Use a custom options class to allow the shared tag lib descriptors
+       to be loaded from jars in the tomcat sar conf/tlds directory. The
+       standard options implementation can only find taglibs based on the
+       class loader classpath.
+      -->
+      <init-param>
+         <param-name>engineOptionsClass</param-name>
+         <param-value>
+            org.jboss.web.tomcat.service.jasper.JspServletOptions</param-value>
+      </init-param>
+      <!-- Specify the jars relative to the jbossweb-tomcat6.sar that should
+        be scanned for common tag lib descriptors to include in every war
+        deployment. -->
+      <init-param>
+         <description>JSTL standard tlds</description>
+         <param-name>tagLibJar0</param-name>
+         <param-value>jstl.jar</param-value>
+      </init-param>
+
+
+      <load-on-startup>3</load-on-startup>
+   </servlet>
+
+
+   <!-- Server Side Includes processing servlet, which processes SSI         -->
+   <!-- directives in HTML pages consistent with similar support in web      -->
+   <!-- servers like Apache.  Traditionally, this servlet is mapped to the   -->
+   <!-- URL pattern "*.shtml".  This servlet supports the following          -->
+   <!-- initialization parameters (default values are in square brackets):   -->
+   <!--                                                                      -->
+   <!--   buffered            Should output from this servlet be buffered?   -->
+   <!--                       (0=false, 1=true)  [0]                         -->
+   <!--                                                                      -->
+   <!--   debug               Debugging detail level for messages logged     -->
+   <!--                       by this servlet.  [0]                          -->
+   <!--                                                                      -->
+   <!--   expires             The number of seconds before a page with SSI   -->
+   <!--                       directives will expire.  [No default]          -->
+   <!--                                                                      -->
+   <!--   isVirtualWebappRelative                                            -->
+   <!--                       Should "virtual" paths be interpreted as       -->
+   <!--                       relative to the context root, instead of       -->
+   <!--                       the server root?  (0=false, 1=true) [0]        -->
+
+   <!--
+       <servlet>
+           <servlet-name>ssi</servlet-name>
+           <servlet-class>
+             org.apache.catalina.ssi.SSIServlet
+           </servlet-class>
+           <init-param>
+             <param-name>buffered</param-name>
+             <param-value>1</param-value>
+           </init-param>
+           <init-param>
+             <param-name>debug</param-name>
+             <param-value>0</param-value>
+           </init-param>
+           <init-param>
+             <param-name>expires</param-name>
+             <param-value>666</param-value>
+           </init-param>
+           <init-param>
+             <param-name>isVirtualWebappRelative</param-name>
+             <param-value>0</param-value>
+           </init-param>
+           <load-on-startup>4</load-on-startup>
+       </servlet>
+   -->
+
+
+   <!-- Common Gateway Includes (CGI) processing servlet, which supports     -->
+   <!-- execution of external applications that conform to the CGI spec      -->
+   <!-- requirements.  Typically, this servlet is mapped to the URL pattern  -->
+   <!-- "/cgi-bin/*", which means that any CGI applications that are         -->
+   <!-- executed must be present within the web application.  This servlet   -->
+   <!-- supports the following initialization parameters (default values     -->
+   <!-- are in square brackets):                                             -->
+   <!--                                                                      -->
+   <!--   cgiPathPrefix        The CGI search path will start at             -->
+   <!--                        webAppRootDir + File.separator + this prefix. -->
+   <!--                        [WEB-INF/cgi]                                 -->
+   <!--                                                                      -->
+   <!--   debug                Debugging detail level for messages logged    -->
+   <!--                        by this servlet.  [0]                         -->
+   <!--                                                                      -->
+   <!--   executable           Name of the exectuable used to run the        -->
+   <!--                        script. [perl]                                -->
+   <!--                                                                      -->
+   <!--   parameterEncoding    Name of parameter encoding to be used with    -->
+   <!--                        CGI servlet.                                  -->
+   <!--                        [System.getProperty("file.encoding","UTF-8")] -->
+   <!--                                                                      -->
+   <!--   passShellEnvironment Should the shell environment variables (if    -->
+   <!--                        any) be passed to the CGI script? [false]     -->
+   <!--                                                                      -->
+   <!-- IMPORTANT: To use the CGI servlet, you also need to rename the       -->
+   <!--            $CATALINA_HOME/server/lib/servlets-cgi.renametojar file   -->
+   <!--            to $CATALINA_HOME/server/lib/servlets-cgi.jar             -->
+
+   <!--
+       <servlet>
+           <servlet-name>cgi</servlet-name>
+           <servlet-class>org.apache.catalina.servlets.CGIServlet</servlet-class>
+           <init-param>
+             <param-name>debug</param-name>
+             <param-value>6</param-value>
+           </init-param>
+           <init-param>
+             <param-name>cgiPathPrefix</param-name>
+             <param-value>WEB-INF/cgi</param-value>
+           </init-param>
+            <load-on-startup>5</load-on-startup>
+       </servlet>
+   -->
+
+
+   <!-- ================ Built In Servlet Mappings ========================= -->
+
+
+   <!-- The servlet mappings for the built in servlets defined above.  Note  -->
+   <!-- that, by default, the CGI and SSI servlets are *not* mapped.  You    -->
+   <!-- must uncomment these mappings (or add them to your application's own -->
+   <!-- web.xml deployment descriptor) to enable these services              -->
+
+   <!-- The mapping for the default servlet -->
+   <servlet-mapping>
+      <servlet-name>default</servlet-name>
+      <url-pattern>/</url-pattern>
+   </servlet-mapping>
+
+   <!-- The mapping for the invoker servlet -->
+   <!--
+       <servlet-mapping>
+           <servlet-name>invoker</servlet-name>
+           <url-pattern>/servlet/*</url-pattern>
+       </servlet-mapping>
+   -->
+
+   <!-- The mapping for the JSP servlet -->
+   <servlet-mapping>
+      <servlet-name>jsp</servlet-name>
+      <url-pattern>*.jsp</url-pattern>
+   </servlet-mapping>
+
+   <servlet-mapping>
+      <servlet-name>jsp</servlet-name>
+      <url-pattern>*.jspx</url-pattern>
+   </servlet-mapping>
+
+   <!-- The mapping for the SSI servlet -->
+   <!--
+       <servlet-mapping>
+           <servlet-name>ssi</servlet-name>
+           <url-pattern>*.shtml</url-pattern>
+       </servlet-mapping>
+   -->
+
+   <!-- The mapping for the CGI Gateway servlet -->
+
+   <!--
+       <servlet-mapping>
+           <servlet-name>cgi</servlet-name>
+           <url-pattern>/cgi-bin/*</url-pattern>
+       </servlet-mapping>
+   -->
+
+
+   <!-- ==================== Default Session Configuration ================= -->
+   <!-- You can set the default session timeout (in minutes) for all newly   -->
+   <!-- created sessions by modifying the value below.                       -->
+
+   <session-config>
+      <session-timeout>30</session-timeout>
+   </session-config>
+
+
+   <!-- ===================== Default MIME Type Mappings =================== -->
+   <!-- When serving static resources, Tomcat will automatically generate    -->
+   <!-- a "Content-Type" header based on the resource's filename extension,  -->
+   <!-- based on these mappings.  Additional mappings can be added here (to  -->
+   <!-- apply to all web applications), or in your own application's web.xml -->
+   <!-- deployment descriptor.                                               -->
+
+   <mime-mapping>
+      <extension>abs</extension>
+      <mime-type>audio/x-mpeg</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>ai</extension>
+      <mime-type>application/postscript</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>aif</extension>
+      <mime-type>audio/x-aiff</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>aifc</extension>
+      <mime-type>audio/x-aiff</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>aiff</extension>
+      <mime-type>audio/x-aiff</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>aim</extension>
+      <mime-type>application/x-aim</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>art</extension>
+      <mime-type>image/x-jg</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>asf</extension>
+      <mime-type>video/x-ms-asf</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>asx</extension>
+      <mime-type>video/x-ms-asf</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>au</extension>
+      <mime-type>audio/basic</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>avi</extension>
+      <mime-type>video/x-msvideo</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>avx</extension>
+      <mime-type>video/x-rad-screenplay</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>bcpio</extension>
+      <mime-type>application/x-bcpio</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>bin</extension>
+      <mime-type>application/octet-stream</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>bmp</extension>
+      <mime-type>image/bmp</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>body</extension>
+      <mime-type>text/html</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>cdf</extension>
+      <mime-type>application/x-cdf</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>cer</extension>
+      <mime-type>application/x-x509-ca-cert</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>class</extension>
+      <mime-type>application/java</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>cpio</extension>
+      <mime-type>application/x-cpio</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>csh</extension>
+      <mime-type>application/x-csh</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>css</extension>
+      <mime-type>text/css</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>dib</extension>
+      <mime-type>image/bmp</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>doc</extension>
+      <mime-type>application/msword</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>dtd</extension>
+      <mime-type>text/plain</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>dv</extension>
+      <mime-type>video/x-dv</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>dvi</extension>
+      <mime-type>application/x-dvi</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>eps</extension>
+      <mime-type>application/postscript</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>etx</extension>
+      <mime-type>text/x-setext</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>exe</extension>
+      <mime-type>application/octet-stream</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>gif</extension>
+      <mime-type>image/gif</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>gtar</extension>
+      <mime-type>application/x-gtar</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>gz</extension>
+      <mime-type>application/x-gzip</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>hdf</extension>
+      <mime-type>application/x-hdf</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>hqx</extension>
+      <mime-type>application/mac-binhex40</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>htc</extension>
+      <mime-type>text/x-component</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>htm</extension>
+      <mime-type>text/html</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>html</extension>
+      <mime-type>text/html</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>hqx</extension>
+      <mime-type>application/mac-binhex40</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>ief</extension>
+      <mime-type>image/ief</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>jad</extension>
+      <mime-type>text/vnd.sun.j2me.app-descriptor</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>jar</extension>
+      <mime-type>application/java-archive</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>java</extension>
+      <mime-type>text/plain</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>jnlp</extension>
+      <mime-type>application/x-java-jnlp-file</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>jpe</extension>
+      <mime-type>image/jpeg</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>jpeg</extension>
+      <mime-type>image/jpeg</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>jpg</extension>
+      <mime-type>image/jpeg</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>js</extension>
+      <mime-type>text/javascript</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>jsf</extension>
+      <mime-type>text/plain</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>jspf</extension>
+      <mime-type>text/plain</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>kar</extension>
+      <mime-type>audio/x-midi</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>latex</extension>
+      <mime-type>application/x-latex</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>m3u</extension>
+      <mime-type>audio/x-mpegurl</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>mac</extension>
+      <mime-type>image/x-macpaint</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>man</extension>
+      <mime-type>application/x-troff-man</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>me</extension>
+      <mime-type>application/x-troff-me</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>mid</extension>
+      <mime-type>audio/x-midi</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>midi</extension>
+      <mime-type>audio/x-midi</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>mif</extension>
+      <mime-type>application/x-mif</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>mov</extension>
+      <mime-type>video/quicktime</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>movie</extension>
+      <mime-type>video/x-sgi-movie</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>mp1</extension>
+      <mime-type>audio/x-mpeg</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>mp2</extension>
+      <mime-type>audio/x-mpeg</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>mp3</extension>
+      <mime-type>audio/x-mpeg</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>mpa</extension>
+      <mime-type>audio/x-mpeg</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>mpe</extension>
+      <mime-type>video/mpeg</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>mpeg</extension>
+      <mime-type>video/mpeg</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>mpega</extension>
+      <mime-type>audio/x-mpeg</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>mpg</extension>
+      <mime-type>video/mpeg</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>mpv2</extension>
+      <mime-type>video/mpeg2</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>ms</extension>
+      <mime-type>application/x-wais-source</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>nc</extension>
+      <mime-type>application/x-netcdf</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>oda</extension>
+      <mime-type>application/oda</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>pbm</extension>
+      <mime-type>image/x-portable-bitmap</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>pct</extension>
+      <mime-type>image/pict</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>pdf</extension>
+      <mime-type>application/pdf</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>pgm</extension>
+      <mime-type>image/x-portable-graymap</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>pic</extension>
+      <mime-type>image/pict</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>pict</extension>
+      <mime-type>image/pict</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>pls</extension>
+      <mime-type>audio/x-scpls</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>png</extension>
+      <mime-type>image/png</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>pnm</extension>
+      <mime-type>image/x-portable-anymap</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>pnt</extension>
+      <mime-type>image/x-macpaint</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>ppm</extension>
+      <mime-type>image/x-portable-pixmap</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>ppt</extension>
+      <mime-type>application/powerpoint</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>ps</extension>
+      <mime-type>application/postscript</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>psd</extension>
+      <mime-type>image/x-photoshop</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>qt</extension>
+      <mime-type>video/quicktime</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>qti</extension>
+      <mime-type>image/x-quicktime</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>qtif</extension>
+      <mime-type>image/x-quicktime</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>ras</extension>
+      <mime-type>image/x-cmu-raster</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>rgb</extension>
+      <mime-type>image/x-rgb</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>rm</extension>
+      <mime-type>application/vnd.rn-realmedia</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>roff</extension>
+      <mime-type>application/x-troff</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>rtf</extension>
+      <mime-type>application/rtf</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>rtx</extension>
+      <mime-type>text/richtext</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>sh</extension>
+      <mime-type>application/x-sh</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>shar</extension>
+      <mime-type>application/x-shar</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>smf</extension>
+      <mime-type>audio/x-midi</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>sit</extension>
+      <mime-type>application/x-stuffit</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>snd</extension>
+      <mime-type>audio/basic</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>src</extension>
+      <mime-type>application/x-wais-source</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>sv4cpio</extension>
+      <mime-type>application/x-sv4cpio</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>sv4crc</extension>
+      <mime-type>application/x-sv4crc</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>swf</extension>
+      <mime-type>application/x-shockwave-flash</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>t</extension>
+      <mime-type>application/x-troff</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>tar</extension>
+      <mime-type>application/x-tar</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>tcl</extension>
+      <mime-type>application/x-tcl</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>tex</extension>
+      <mime-type>application/x-tex</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>texi</extension>
+      <mime-type>application/x-texinfo</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>texinfo</extension>
+      <mime-type>application/x-texinfo</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>tif</extension>
+      <mime-type>image/tiff</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>tiff</extension>
+      <mime-type>image/tiff</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>tr</extension>
+      <mime-type>application/x-troff</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>tsv</extension>
+      <mime-type>text/tab-separated-values</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>txt</extension>
+      <mime-type>text/plain</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>ulw</extension>
+      <mime-type>audio/basic</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>ustar</extension>
+      <mime-type>application/x-ustar</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>xbm</extension>
+      <mime-type>image/x-xbitmap</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>xht</extension>
+      <mime-type>application/xhtml</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>xhtml</extension>
+      <mime-type>application/xhtml</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>xml</extension>
+      <mime-type>text/xml</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>xpm</extension>
+      <mime-type>image/x-xpixmap</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>xsl</extension>
+      <mime-type>text/xml</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>xwd</extension>
+      <mime-type>image/x-xwindowdump</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>wav</extension>
+      <mime-type>audio/x-wav</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>svg</extension>
+      <mime-type>image/svg</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>svgz</extension>
+      <mime-type>image/svg</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>vsd</extension>
+      <mime-type>application/x-visio</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <!-- Wireless Bitmap -->
+      <extension>wbmp</extension>
+      <mime-type>image/vnd.wap.wbmp</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <!-- WML Source -->
+      <extension>wml</extension>
+      <mime-type>text/vnd.wap.wml</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <!-- Compiled WML -->
+      <extension>wmlc</extension>
+      <mime-type>application/vnd.wap.wmlc</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <!-- WML Script Source -->
+      <extension>wmls</extension>
+      <mime-type>text/vnd.wap.wmlscript</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <!-- Compiled WML Script -->
+      <extension>wmlscriptc</extension>
+      <mime-type>application/vnd.wap.wmlscriptc</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>wrl</extension>
+      <mime-type>x-world/x-vrml</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>Z</extension>
+      <mime-type>application/x-compress</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>z</extension>
+      <mime-type>application/x-compress</mime-type>
+   </mime-mapping>
+   <mime-mapping>
+      <extension>zip</extension>
+      <mime-type>application/zip</mime-type>
+   </mime-mapping>
+
+
+   <!-- ==================== Default Welcome File List ===================== -->
+   <!-- When a request URI refers to a directory, the default servlet looks  -->
+   <!-- for a "welcome file" within that directory and, if present,          -->
+   <!-- to the corresponding resource URI for display.  If no welcome file   -->
+   <!-- is present, the default servlet either serves a directory listing,   -->
+   <!-- or returns a 404 status, depending on how it is configured.          -->
+   <!--                                                                      -->
+   <!-- If you define welcome files in your own application's web.xml        -->
+   <!-- deployment descriptor, that list *replaces* the list configured      -->
+   <!-- here, so be sure that you include any of the default values that     -->
+   <!-- you wish to include.                                                 -->
+
+   <welcome-file-list>
+      <welcome-file>index.html</welcome-file>
+      <welcome-file>index.htm</welcome-file>
+      <welcome-file>index.jsp</welcome-file>
+   </welcome-file-list>
+
+</web-app>

Added: projects/jboss-jsf-int/trunk/cargo/ASModifications/deployers/jsf.deployer/META-INF/jsf-integration-deployer-jboss-beans.xml
===================================================================
--- projects/jboss-jsf-int/trunk/cargo/ASModifications/deployers/jsf.deployer/META-INF/jsf-integration-deployer-jboss-beans.xml	                        (rev 0)
+++ projects/jboss-jsf-int/trunk/cargo/ASModifications/deployers/jsf.deployer/META-INF/jsf-integration-deployer-jboss-beans.xml	2009-03-31 20:22:31 UTC (rev 86545)
@@ -0,0 +1,57 @@
+<?xml version="1.0" encoding="UTF-8"?>
+
+<!--
+    JBoss JSF + JBossAS integration
+-->
+<deployment xmlns="urn:jboss:bean-deployer:2.0">
+
+  <!-- JSF deployer -->
+  <bean name="JSFDeployer" class="org.jboss.jsf.integration.JSFDeployer">
+    
+    <!--
+      * Specify the servlet classes that signal this deployer to add JSF to a WAR. 
+    -->
+    <property name="facesServlets">
+       <collection elementClass="java.lang.String">
+          <value>javax.faces.webapp.FacesServlet</value>
+       </collection>
+    </property>
+    
+    <!--
+      * Specify the name of the default JSF profile.
+    -->
+    <property name="defaultJSFImplementation">
+       <value>Mojarra-1.2</value>
+    </property>
+    
+    <!-- 
+      *  Define where to find JSF implementations.  The key is the name
+      *  of the JSF profile.  The value is a URL to the directory where
+      *  the implementation resides.  The implementation should include any 
+      *  jars that the implementation requires.  It should also include a 
+      *  web.xml file in the root.  Elements in the web.xml will be applied 
+      *  to all web applications applications that use the profile.
+      
+      Example URLs:
+            ${jboss.server.home.url}/deployers/jsf.deployer/Mojarra1.2
+                 scans Mojarra 1.2 for jars and web.xml
+            file:/myproject/jsflib
+                 scans /myproject/jsflib
+            http://www.test.com/jsfimpl/myfaces/
+                 scans the specified WebDAV location
+    -->
+    <property name="jsfImplementations">
+      <map keyClass="java.lang.String" valueClass="java.lang.String">
+        <entry>
+          <key>Mojarra-1.2</key>
+          <value>${jboss.server.home.url}deployers/jsf.deployer/Mojarra-1.2</value>
+        </entry>
+        <entry>
+          <key>Mojarra-2.0</key>
+          <value>${jboss.server.home.url}deployers/jsf.deployer/Mojarra-2.0</value>
+        </entry>
+      </map>   
+    </property>
+  </bean>
+
+</deployment>

Added: projects/jboss-jsf-int/trunk/cargo/ASModifications/deployers/jsf.deployer/Mojarra-1.2/web.xml
===================================================================
--- projects/jboss-jsf-int/trunk/cargo/ASModifications/deployers/jsf.deployer/Mojarra-1.2/web.xml	                        (rev 0)
+++ projects/jboss-jsf-int/trunk/cargo/ASModifications/deployers/jsf.deployer/Mojarra-1.2/web.xml	2009-03-31 20:22:31 UTC (rev 86545)
@@ -0,0 +1,50 @@
+<?xml version="1.0" encoding="ISO-8859-1"?>
+<web-app xmlns="http://java.sun.com/xml/ns/javaee"
+   xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
+   xsi:schemaLocation="http://java.sun.com/xml/ns/javaee http://java.sun.com/xml/ns/javaee/web-app_2_5.xsd"
+   version="2.5">
+   <!-- ======================== Introduction ============================== -->
+   <!-- This document defines default values for *all* web applications      -->
+   <!-- loaded into this instance of Tomcat.  As each application is         -->
+   <!-- deployed, this file is processed, followed by the                    -->
+   <!-- "/WEB-INF/web.xml" deployment descriptor from your own               -->
+   <!-- applications.                                                        -->
+   <!--                                                                      -->
+   <!-- WARNING:  Do not configure application-specific resources here!      -->
+   <!-- They should go in the "/WEB-INF/web.xml" file in your application.   -->
+
+   <!-- =========== Common Context Params ================================== -->
+
+   <!-- Regular expression to determine if two different URLs actually point -->
+   <!-- to the same jar file.  This keeps faces-config files from being      -->
+   <!-- read twice.                                                          -->
+   <context-param>
+     <param-name>com.sun.faces.duplicateJARPattern</param-name>
+     <param-value>^tmp\d+(\S*\.jar)</param-value>
+   </context-param>
+    
+   <!-- JBossInjectionProvider provides resource injection for managed beans. -->
+   <!-- See JSF 1.2 spec section 5.4 for details.                             -->
+   <context-param>
+     <param-name>com.sun.faces.injectionProvider</param-name>
+     <param-value>org.jboss.web.jsf.integration.injection.JBossDelegatingInjectionProvider</param-value>
+   </context-param>
+   
+   <!-- ================== Common filter Configuration ==================== -->
+   
+	
+   <!-- ================== Common Listener Configuration ==================== -->
+   <!-- Configures JSF for a web application if the javax.faces.webapp.FacesServlet is declared -->
+   <!-- in web.xml.                                                                             -->
+   <listener>
+     <listener-class>org.jboss.jsf.integration.config.JBossJSFConfigureListener</listener-class>
+   </listener>
+
+   <!-- Listens to all web app lifecycle events so that @PreDestroy can be called on -->
+   <!-- JSF managed beans that go out of scope.  You can comment this out if you     -->
+   <!-- don't use JSF or you don't use annotations on your managed beans.            -->
+   <listener>
+     <listener-class>com.sun.faces.application.WebappLifecycleListener</listener-class>
+   </listener>
+
+</web-app>

Added: projects/jboss-jsf-int/trunk/cargo/ASModifications/deployers/jsf.deployer/Mojarra-2.0/web.xml
===================================================================
--- projects/jboss-jsf-int/trunk/cargo/ASModifications/deployers/jsf.deployer/Mojarra-2.0/web.xml	                        (rev 0)
+++ projects/jboss-jsf-int/trunk/cargo/ASModifications/deployers/jsf.deployer/Mojarra-2.0/web.xml	2009-03-31 20:22:31 UTC (rev 86545)
@@ -0,0 +1,50 @@
+<?xml version="1.0" encoding="ISO-8859-1"?>
+<web-app xmlns="http://java.sun.com/xml/ns/javaee"
+   xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
+   xsi:schemaLocation="http://java.sun.com/xml/ns/javaee http://java.sun.com/xml/ns/javaee/web-app_2_5.xsd"
+   version="2.5">
+   <!-- ======================== Introduction ============================== -->
+   <!-- This document defines default values for *all* web applications      -->
+   <!-- loaded into this instance of Tomcat.  As each application is         -->
+   <!-- deployed, this file is processed, followed by the                    -->
+   <!-- "/WEB-INF/web.xml" deployment descriptor from your own               -->
+   <!-- applications.                                                        -->
+   <!--                                                                      -->
+   <!-- WARNING:  Do not configure application-specific resources here!      -->
+   <!-- They should go in the "/WEB-INF/web.xml" file in your application.   -->
+
+   <!-- =========== Common Context Params ================================== -->
+
+   <!-- Regular expression to determine if two different URLs actually point -->
+   <!-- to the same jar file.  This keeps faces-config files from being      -->
+   <!-- read twice.                                                          -->
+   <context-param>
+     <param-name>com.sun.faces.duplicateJARPattern</param-name>
+     <param-value>^tmp\d+(\S*\.jar)</param-value>
+   </context-param>
+    
+   <!-- JBossInjectionProvider provides resource injection for managed beans. -->
+   <!-- See JSF 1.2 spec section 5.4 for details.                             -->
+   <context-param>
+     <param-name>com.sun.faces.injectionProvider</param-name>
+     <param-value>org.jboss.web.jsf.integration.injection.JBossDelegatingInjectionProvider</param-value>
+   </context-param>
+   
+   <!-- ================== Common filter Configuration ==================== -->
+   
+	
+   <!-- ================== Common Listener Configuration ==================== -->
+   <!-- Configures JSF for a web application if the javax.faces.webapp.FacesServlet is declared -->
+   <!-- in web.xml.                                                                             -->
+   <listener>
+     <listener-class>org.jboss.jsf.integration.config.JBossJSFConfigureListener</listener-class>
+   </listener>
+
+   <!-- Listens to all web app lifecycle events so that @PreDestroy can be called on -->
+   <!-- JSF managed beans that go out of scope.  You can comment this out if you     -->
+   <!-- don't use JSF or you don't use annotations on your managed beans.            -->
+   <listener>
+     <listener-class>com.sun.faces.application.WebappLifecycleListener</listener-class>
+   </listener>
+
+</web-app>

Modified: projects/jboss-jsf-int/trunk/cargo/pom.xml
===================================================================
--- projects/jboss-jsf-int/trunk/cargo/pom.xml	2009-03-31 20:01:05 UTC (rev 86544)
+++ projects/jboss-jsf-int/trunk/cargo/pom.xml	2009-03-31 20:22:31 UTC (rev 86545)
@@ -28,6 +28,14 @@
     
     <dependency>
        <groupId>org.jboss.jsf.integration</groupId>
+       <artifactId>jboss-jsf-20test</artifactId>
+       <version>${project.version}</version>
+       <scope>test</scope>
+       <type>war</type>
+    </dependency>
+    
+    <dependency>
+       <groupId>org.jboss.jsf.integration</groupId>
        <artifactId>jboss-jsf-jsfbundledtest</artifactId>
        <version>${project.version}</version>
        <scope>test</scope>
@@ -72,12 +80,13 @@
                 <home>${project.build.directory}/cargoconfig</home>
                 
                 <files>
+           <!--   only need this for AS5.0.0.GA,  AS5.1 doesn't need it    
                   <copy>
                     <file>${project.build.directory}/cargoconfig/conf/bootstrap-norepo.xml</file>
                     <tofile>conf/bootstrap.xml</tofile>
                     <configfile>false</configfile>
                     <overwrite>true</overwrite>
-                  </copy>
+                  </copy>  -->
                   <copy>
                     <file>${project.build.directory}/dependency/jboss-jsfunit-microdeployer.jar</file>
                     <todir>deployers</todir>
@@ -96,6 +105,54 @@
                      <configfile>false</configfile>
                      <overwrite>true</overwrite>
                   </copy>
+                  <copy>
+                     <file>${basedir}/ASModifications/deploy/jbossweb.sar/jsf-libs</file>
+                     <todir>deploy/jbossweb.sar/jsf-libs</todir>
+                     <configfile>false</configfile>
+                     <overwrite>true</overwrite>
+                  </copy>
+                  <copy>
+                     <file>${basedir}/ASModifications/deploy/jbossweb.sar/META-INF/jboss-structure.xml</file>
+                     <todir>deploy/jbossweb.sar/META-INF</todir>
+                     <configfile>false</configfile>
+                     <overwrite>true</overwrite>
+                  </copy>
+                  <copy>
+                     <file>${basedir}/ASModifications/deployers/jbossweb.deployer/web.xml</file>
+                     <todir>deployers/jbossweb.deployer</todir>
+                     <configfile>false</configfile>
+                     <overwrite>true</overwrite>
+                  </copy>
+                  <copy>
+                     <file>${basedir}/ASModifications/deployers/jsf.deployer/META-INF/jsf-integration-deployer-jboss-beans.xml</file>
+                     <todir>deployers/jsf.deployer/META-INF</todir>
+                     <configfile>false</configfile>
+                     <overwrite>true</overwrite>
+                  </copy>
+                  <copy>
+                     <file>${project.build.directory}/dependency/Mojarra-1.2</file>
+                     <todir>deployers/jsf.deployer/Mojarra-1.2</todir>
+                     <configfile>false</configfile>
+                     <overwrite>true</overwrite>
+                  </copy>
+                  <copy>
+                     <file>${basedir}/ASModifications/deployers/jsf.deployer/Mojarra-1.2/web.xml</file>
+                     <todir>deployers/jsf.deployer/Mojarra-1.2</todir>
+                     <configfile>false</configfile>
+                     <overwrite>true</overwrite>
+                  </copy>
+                  <copy>
+                     <file>${project.build.directory}/dependency/Mojarra-2.0</file>
+                     <todir>deployers/jsf.deployer/Mojarra-2.0</todir>
+                     <configfile>false</configfile>
+                     <overwrite>true</overwrite>
+                  </copy>
+                  <copy>
+                     <file>${basedir}/ASModifications/deployers/jsf.deployer/Mojarra-2.0/web.xml</file>
+                     <todir>deployers/jsf.deployer/Mojarra-2.0</todir>
+                     <configfile>false</configfile>
+                     <overwrite>true</overwrite>
+                  </copy>
                 </files>
                 
                 <deployables>
@@ -104,6 +161,10 @@
                     <type>war</type>
                   </deployable>
                   <deployable>
+                    <location>${project.build.directory}/dependency/jboss-jsf-20test-jsfunit.war</location>
+                    <type>war</type>
+                  </deployable>
+                  <deployable>
                     <location>${project.build.directory}/dependency/jboss-jsf-jsfbundledtest-jsfunit.war</location>
                     <type>war</type>
                   </deployable>
@@ -156,6 +217,13 @@
                         </artifactItem>
                         <artifactItem>
                            <groupId>org.jboss.jsf.integration</groupId>
+                           <artifactId>jboss-jsf-20test</artifactId>
+                           <version>${project.version}</version>
+                           <type>war</type>
+                           <destFileName>jboss-jsf-20test-jsfunit.war</destFileName>
+                        </artifactItem>
+                        <artifactItem>
+                           <groupId>org.jboss.jsf.integration</groupId>
                            <artifactId>jboss-jsf-jsfbundledtest</artifactId>
                            <version>${project.version}</version>
                            <type>war</type>
@@ -168,6 +236,34 @@
                            <type>jar</type>
                            <destFileName>jboss-jsfunit-microdeployer.jar</destFileName>
                         </artifactItem>
+                        <artifactItem>
+                           <groupId>javax.faces</groupId>
+                           <artifactId>jsf-api</artifactId>
+                           <version>${jsf12-version}</version>
+                           <type>jar</type>
+                           <destFileName>Mojarra-1.2/jsf-api.jar</destFileName>
+                        </artifactItem>
+                        <artifactItem>
+                           <groupId>javax.faces</groupId>
+                           <artifactId>jsf-impl</artifactId>
+                           <version>${jsf12-version}</version>
+                           <type>jar</type>
+                           <destFileName>Mojarra-1.2/jsf-impl.jar</destFileName>
+                        </artifactItem>
+                        <artifactItem>
+                           <groupId>javax.faces</groupId>
+                           <artifactId>jsf-api</artifactId>
+                           <version>${jsf20-version}</version>
+                           <type>jar</type>
+                           <destFileName>Mojarra-2.0/jsf-api.jar</destFileName>
+                        </artifactItem>
+                        <artifactItem>
+                           <groupId>javax.faces</groupId>
+                           <artifactId>jsf-impl</artifactId>
+                           <version>${jsf20-version}</version>
+                           <type>jar</type>
+                           <destFileName>Mojarra-2.0/jsf-impl.jar</destFileName>
+                        </artifactItem>
                      </artifactItems>
                   </configuration>
                </execution>

Added: projects/jboss-jsf-int/trunk/cargo/src/test/java/org/jboss/jsf/integration/test/DeployJSF20Test.java
===================================================================
--- projects/jboss-jsf-int/trunk/cargo/src/test/java/org/jboss/jsf/integration/test/DeployJSF20Test.java	                        (rev 0)
+++ projects/jboss-jsf-int/trunk/cargo/src/test/java/org/jboss/jsf/integration/test/DeployJSF20Test.java	2009-03-31 20:22:31 UTC (rev 86545)
@@ -0,0 +1,68 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2009, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+
+package org.jboss.jsf.integration.test;
+
+import java.io.IOException;
+import junit.framework.Test;
+import junit.framework.TestSuite;
+import org.apache.cactus.ServletTestCase;
+import org.jboss.jsfunit.framework.Environment;
+import org.jboss.jsfunit.jsfsession.JSFSession;
+
+/**
+ * The JSFUnit Environment class allows you to programatically find which version
+ * of JSF you are running.  Because this is the test for the Environment class,
+ * the JSF version is known beforehand and loaded via a properties file.
+ * 
+ * @author Stan Silvert
+ */
+public class DeployJSF20Test extends ServletTestCase
+{
+   public DeployJSF20Test()
+   {
+      System.setProperty("cactus.contextURL", "http://localhost:8080/jboss-jsf-20test-jsfunit");
+   }
+   
+   public void setUp() throws IOException
+   {
+      JSFSession jsfSession = new JSFSession("/index.faces");
+   }
+   
+   /**
+    * @return the suite of tests being tested
+    */
+   public static Test suite()
+   {
+      return new TestSuite( DeployJSF20Test.class    );
+   }
+   
+   public void testRunningInJSF12()
+   {
+      assertEquals(2, Environment.getJSFMajorVersion());
+      assertEquals(0, Environment.getJSFMinorVersion());
+      assertTrue(Environment.is12Compatible());
+      assertTrue(Environment.is20Compatible());
+   }
+   
+      
+}


Property changes on: projects/jboss-jsf-int/trunk/jsf-deployer
___________________________________________________________________
Name: svn:ignore
   + target


Modified: projects/jboss-jsf-int/trunk/jsf-deployer/src/main/java/org/jboss/jsf/integration/JSFDeployer.java
===================================================================
--- projects/jboss-jsf-int/trunk/pom.xml	2009-03-31 20:01:05 UTC (rev 86544)
+++ projects/jboss-jsf-int/trunk/pom.xml	2009-03-31 20:22:31 UTC (rev 86545)
@@ -21,6 +21,11 @@
     <url>http://viewvc.jboss.org/cgi-bin/viewvc.cgi/jbossas/projects/jboss-jsf-int/trunk/</url>
   </scm>
   
+  <properties>
+    <jsf12-version>1.2_12</jsf12-version>
+    <jsf20-version>2.0.0-PR2</jsf20-version>
+  </properties>
+  
   <modules>
      <module>jsf-deployer</module>
      <module>testwar</module>
@@ -65,13 +70,13 @@
        <dependency>
           <groupId>javax.faces</groupId>
           <artifactId>jsf-api</artifactId>
-          <version>1.2_12</version>
+          <version>${jsf12-version}</version>
        </dependency>
        
        <dependency>
           <groupId>javax.faces</groupId>
           <artifactId>jsf-impl</artifactId>
-          <version>1.2_12</version>
+          <version>${jsf12-version}</version>
        </dependency>
        
        <dependency>


Property changes on: projects/jboss-jsf-int/trunk/testwar
___________________________________________________________________
Name: svn:ignore
   + target





More information about the jboss-cvs-commits mailing list
--- projects/jboss-jsf-int/trunk/jsf-deployer/src/main/java/org/jboss/jsf/integration/JSFDeployer.java	2009-03-31 20:01:05 UTC (rev 86544)
+++ projects/jboss-jsf-int/trunk/jsf-deployer/src/main/java/org/jboss/jsf/integration/JSFDeployer.java	2009-03-31 20:22:31 UTC (rev 86545)
@@ -27,6 +27,7 @@
 
 import java.util.ArrayList;
 import java.util.Collection;
+import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
@@ -74,11 +75,11 @@
    
    private Collection<String> facesServlets;
    
-   private Web25MetaData jsfunitWebMD;
-   private boolean disabled = false;
+   private Web25MetaData jsfWebMD;
    
    private String defaultJSFImplementation;
    private Map<String,String> jsfImplementations;
+   private Map<String,Web25MetaData> jsfImplWebXmls = new HashMap<String,Web25MetaData>();
 
    /**
     * Unmarshall factory used for parsing shared web.xml.
@@ -91,14 +92,23 @@
    public JSFDeployer()
    {
       super(JBossWebMetaData.class);
+      
       // We have to run before the classloading is setup
       setStage(DeploymentStages.POST_PARSE);
       
+      
+   }
+   
+   public void start()
+   {
+      log.info("Initializing JSF Integration Deployer...");
+      
       // only need to do this once for each JSF profile
       parseJSFImplWebMetaData();
       
       log.info("JBoss JSF Integration Deployer is initialized");
    }
+
    
    private String findDeployerBaseURL()
    {
@@ -109,23 +119,30 @@
 
    private void parseJSFImplWebMetaData()
    {
-      // Parse JSFUnit web.xml
       Unmarshaller unmarshaller = factory.newUnmarshaller();
-      URL webXml = this.getClass().getClassLoader().getResource("META-INF/web.xml");
-      if (webXml == null)
-         throw new IllegalStateException("Unable to find jsfunit web.xml");
       
-      SchemaBinding schema = JBossXBBuilder.build(Web25MetaData.class);
-      
-      try
+      for (Iterator<String> impls = jsfImplementations.keySet().iterator(); impls.hasNext();)
       {
-         this.jsfunitWebMD = (Web25MetaData) unmarshaller.unmarshal(webXml.toString(), schema);
+         String jsfImpl = impls.next();
+         String implLocation = jsfImplementations.get(jsfImpl);
+         
+         //URL webXml = this.getClass().getClassLoader().getResource(implLocation + "/web.xml");
+        // if (webXml == null)
+        //    log.error("Unable to find jsf web.xml for JSF implementation at " + implLocation);
+
+         SchemaBinding schema = JBossXBBuilder.build(Web25MetaData.class);
+
+         try
+         {
+            //jsfImplWebXmls.put(jsfImpl, (Web25MetaData) unmarshaller.unmarshal(webXml.toString(), schema));
+            jsfImplWebXmls.put(jsfImpl, (Web25MetaData) unmarshaller.unmarshal(implLocation + "/web.xml", schema));
+            log.info("Parsed web.xml for JSF profile at " + implLocation);
+         }
+         catch (JBossXBException e)
+         {
+            log.error("Unable to parse web.xml at " + implLocation, e);
+         }
       }
-      catch (JBossXBException e)
-      {
-         this.disabled = true;
-         log.error("Unable to parse jsfunit web.xml", e);
-      }
    }
    
    /**
@@ -151,7 +168,8 @@
       this.jsfImplementations = jsfImplementations;
    }
    
-   private boolean isJSFDeployment(JBossWebMetaData metaData) {
+   private boolean isJSFDeployment(JBossWebMetaData metaData) 
+   {
       for (Iterator<JBossServletMetaData> servlets = metaData.getServlets().iterator(); servlets.hasNext();)
       {
          if (this.facesServlets.contains(servlets.next().getServletClass())) return true;
@@ -164,11 +182,6 @@
    public void deploy(VFSDeploymentUnit unit, JBossWebMetaData metaData) throws DeploymentException
    {
       if (!isJSFDeployment(metaData)) return;
-      if (disabled)
-      {
-         log.warn(unit.getSimpleName() + " could not be deployed.  JSF Deployer disabled from previous errors.");
-         return;
-      }
       
       //mergeWebXml(metaData);
 
@@ -214,38 +227,38 @@
       }
    } */
    
    // merge JSFUnit's web.xml with the WAR's web.xml
    private void mergeWebXml(JBossWebMetaData metaData)
    {
       FiltersMetaData filters = metaData.getFilters();
       if (filters == null) filters = new FiltersMetaData();
-      filters.addAll(jsfunitWebMD.getFilters());
+      filters.addAll(jsfWebMD.getFilters());
       metaData.setFilters(filters);
       
       List<FilterMappingMetaData> filterMappings = metaData.getFilterMappings();
       if (filterMappings == null) filterMappings = new ArrayList<FilterMappingMetaData>();
-      filterMappings.addAll(jsfunitWebMD.getFilterMappings());
+      filterMappings.addAll(jsfWebMD.getFilterMappings());
       metaData.setFilterMappings(filterMappings);
       
       JBossServletsMetaData servlets = metaData.getServlets();
       if (servlets == null) servlets = new JBossServletsMetaData();
-      ServletsMetaData servletsMD = jsfunitWebMD.getServlets();
+      ServletsMetaData servletsMD = jsfWebMD.getServlets();
       servlets.addAll(makeJBossServletsMetaData(servletsMD));
       metaData.setServlets(servlets);
       
       List<ServletMappingMetaData> servletMappings = metaData.getServletMappings();
       if (servletMappings == null) servletMappings = new ArrayList<ServletMappingMetaData>();
-      servletMappings.addAll(jsfunitWebMD.getServletMappings());
+      servletMappings.addAll(jsfWebMD.getServletMappings());
       metaData.setServletMappings(servletMappings);
       
       List<ParamValueMetaData> contextParams = metaData.getContextParams();
       if (contextParams == null) contextParams = new ArrayList<ParamValueMetaData>();
-      contextParams.addAll(jsfunitWebMD.getContextParams());
+      contextParams.addAll(jsfWebMD.getContextParams());
       metaData.setContextParams(contextParams);
       
       List<ListenerMetaData> listeners = metaData.getListeners();
       if (listeners == null) listeners = new ArrayList<ListenerMetaData>();
-      listeners.addAll(jsfunitWebMD.getListeners());
+      listeners.addAll(jsfWebMD.getListeners());
       metaData.setListeners(listeners);
    }
    
@@ -214,38 +227,38 @@
    } */
    
-   // merge JSFUnit's web.xml with the WAR's web.xml
+   // merge the JSF impl's web.xml with the WAR's web.xml
    private void mergeWebXml(JBossWebMetaData metaData)
    {


Property changes on: projects/jboss-jsf-int/trunk/jsf12test
___________________________________________________________________
Name: svn:ignore
   + target



Property changes on: projects/jboss-jsf-int/trunk/jsf20test
___________________________________________________________________
Name: svn:ignore
   + target


Modified: projects/jboss-jsf-int/trunk/pom.xml
===================================================================